==> wargus-2.1_2.tbz: share/wargus/scripts/credits.lua <==
--       _________ __                 __                               
--      /   _____//  |_____________ _/  |______     ____  __ __  ______
--      \_____  \\   __\_  __ \__  \\   __\__  \   / ___\|  |  \/  ___/
--      /        \|  |  |  | \// __ \|  |  / __ \_/ /_/  >  |  /\___ \ 
--     /_______  /|__|  |__|  (____  /__| (____  /\___  /|____//____  >
--             \/                  \/          \//_____/            \/ 
--  ______________________                           ______________________
--                        T H E   W A R   B E G I N S
--         Stratagus - A free fantasy real time strategy game engine
--
--      credits.lua - The credits of the engine.
--
--      (c) Copyright 2002-2004 by Jimmy Salmon.
--
--      This program is free software; you can redistribute it and/or modify
--      it under the terms of the GNU General Public License as published by
--      the Free Software Foundation; either version 2 of the License, or
--      (at your option) any later version.
--  
--      This program is distributed in the hope that it will be useful,
--      but WITHOUT ANY WARRANTY; without even the implied warranty of
--      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--      GNU General Public License for more details.
--  
--      You should have received a copy of the GNU General Public License
--      along with this program; if not, write to the Free Software
--      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
--
--      $Id: credits.lua,v 1.6 2004/06/26 19:36:52 jsalmon3 Exp $

Credits(
	"background", "graphics/ui/Credits_background.png",
	"title", "Programmers",
	"name", "  Jimmy Salmon",
	"name", "  Russell Smith",
	"name", "  Nehal Mistry",
	"title", "Patches",
	"name", "  Martin Renold",
	"name", "  Carlos Perello Marin",
	"name", "  Pludov",
	"title", "Past Programmers",
	"name", "  Andreas 'Ari' Arens",
	"name", "  Lutz 'Johns' Sammer",
	"name", "  Edgar 'Froese' Toernig",
	"name", "  Crestez Leonard",
	"name", "  Mark Pazolli",
	"name", "  Valery Shchedrin",
	"name", "  Iftikhar Rathore",
	"name", "  Charles K Hardin",
	"name", "  Fabrice Rossi",
	"name", "  DigiCat",
	"name", "  Josh Cogliati",
	"name", "  Patrick Mullen",
	"name", "  Vladi Belperchinov-Shabanski",
	"name", "  Cris Daniluk",
	"name", "  Patrice Fortier",
	"name", "  FT Rathore",
	"name", "  Trent Piepho",
	"name", "  Jon Gabrielson",
	"name", "  Lukas Hejtmanek",
	"name", "  Steinar Hamre",
	"name", "  Ian Farmer",
	"name", "  Sebastian Drews",
	"name", "  Jarek Sobieszek",
	"name", "  Anthony Towns",
	"name", "  Stefan Dirsch",
	"name", "  Al Koskelin",
	"name", "  George J. Carrette",
	"name", "  Dirk 'Guardian' Richartz",
	"name", "  Michael O'Reilly",
	"name", "  Dan Hensley",
	"name", "  Sean McMillian",
	"name", "  Mike Earl",
	"name", "  Ian Turner",
	"name", "  David Slimp",
	"name", "  Iuri Fiedoruk",
	"name", "  Luke Mauldin",
	"name", "  Nathan Adams",
	"name", "  Stephan Rasenberger",
	"name", "  Dave Reed",
	"name", "  Josef Spillner",
	"name", "  James Dessart",
	"name", "  Jan Uerpmann",
	"name", "  Aaron Berger",
	"name", "  Latimerius",
	"name", "  Antonis Chaniotis",
	"name", "  Samuel Hays",
	"name", "  David Martinez Moreno",
	"name", "  Flavio Silvestrow",
	"name", "  Daniel Burrows",
	"name", "  Dave Turner",
	"name", "  Ben Hines",
	"name", "  Kachalov Anton",
	"title", "Past Patch Contributors",
	"name", "  Martin Hajduch",
	"name", "  Jeff Binder",
	"name", "  Ludovic",
	"name", "  Juan Pablo",
	"name", "  Phil Hannent",
	"name", "  Alexander MacLean",
	"name", "",
	"name", "Code used:",
	"name", "  SDL Copyright by Sam Lantinga",
	"name", "  ZZIPLIB Copyright by Tomi Ollil and Guido Draheim",
	"name", "  ZLIB Copyright by Jean-loup Gailly and Mark Adler",
	"name", "  BZ2LIB Copyright by Julian Seward",
	"name", "  PNG Copyright by Glenn Randers-Pehrson",
	"name", "  libmodplug Copyright by Kenton Varda & Olivier Lapique",
	"name", "  MAD Copyright by Robert Leslie",
	"name", "  OGG/Vorbis Copyright by Xiph.org Foundation",
	"name", "  FLAC Copyright by Josh Coalson",
	"name", "  VP3 codec Copyright by On2 Technologies Inc.",
	"name", "",
	"name", "",
	"comment", "The Stratagus Team thanks all the people who have contributed",
	"comment", "patches, bug reports, ideas."
)

==> wargus-2.2.4.tbz: share/wargus/scripts/credits.lua <==
--       _________ __                 __
--      /   _____//  |_____________ _/  |______     ____  __ __  ______
--      \_____  \\   __\_  __ \__  \\   __\__  \   / ___\|  |  \/  ___/
--      /        \|  |  |  | \// __ \|  |  / __ \_/ /_/  >  |  /\___ \ 
--     /_______  /|__|  |__|  (____  /__| (____  /\___  /|____//____  >
--             \/                  \/          \//_____/            \/ 
--  ______________________                           ______________________
--                        T H E   W A R   B E G I N S
--         Stratagus - A free fantasy real time strategy game engine
--
--      credits.lua - The credits of the engine.
--
--      (c) Copyright 2002-2005 by Jimmy Salmon.
--
--      This program is free software; you can redistribute it and/or modify
--      it under the terms of the GNU General Public License as published by
--      the Free Software Foundation; either version 2 of the License, or
--      (at your option) any later version.
--  
--      This program is distributed in the hope that it will be useful,
--      but WITHOUT ANY WARRANTY; without even the implied warranty of
--      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--      GNU General Public License for more details.
--  
--      You should have received a copy of the GNU General Public License
--      along with this program; if not, write to the Free Software
--      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
--
--      $Id: credits.lua 1322 2005-11-20 19:18:39Z jarod42 $

Credits(
	"background", "ui/Credits_background.png",
	"title", "Programmers",
	"name", "  Jimmy Salmon",
	"name", "  Russell Smith",
	"name", "  Nehal Mistry",
	"name", "  Joris Dauphin",
	"title", "Patches",
	"name", "  Martin Renold",
	"name", "  Carlos Perello Marin",
	"name", "  Pludov",
	"title", "Past Programmers",
	"name", "  Andreas 'Ari' Arens",
	"name", "  Lutz 'Johns' Sammer",
	"name", "  Edgar 'Froese' Toernig",
	"name", "  Crestez Leonard",
	"name", "  Mark Pazolli",
	"name", "  Valery Shchedrin",
	"name", "  Iftikhar Rathore",
	"name", "  Charles K Hardin",
	"name", "  Fabrice Rossi",
	"name", "  DigiCat",
	"name", "  Josh Cogliati",
	"name", "  Patrick Mullen",
	"name", "  Vladi Belperchinov-Shabanski",
	"name", "  Cris Daniluk",
	"name", "  Patrice Fortier",
	"name", "  FT Rathore",
	"name", "  Trent Piepho",
	"name", "  Jon Gabrielson",
	"name", "  Lukas Hejtmanek",
	"name", "  Steinar Hamre",
	"name", "  Ian Farmer",
	"name", "  Sebastian Drews",
	"name", "  Jarek Sobieszek",
	"name", "  Anthony Towns",
	"name", "  Stefan Dirsch",
	"name", "  Al Koskelin",
	"name", "  George J. Carrette",
	"name", "  Dirk 'Guardian' Richartz",
	"name", "  Michael O'Reilly",
	"name", "  Dan Hensley",
	"name", "  Sean McMillian",
	"name", "  Mike Earl",
	"name", "  Ian Turner",
	"name", "  David Slimp",
	"name", "  Iuri Fiedoruk",
	"name", "  Luke Mauldin",
	"name", "  Nathan Adams",
	"name", "  Stephan Rasenberger",
	"name", "  Dave Reed",
	"name", "  Josef Spillner",
	"name", "  James Dessart",
	"name", "  Jan Uerpmann",
	"name", "  Aaron Berger",
	"name", "  Latimerius",
	"name", "  Antonis Chaniotis",
	"name", "  Samuel Hays",
	"name", "  David Martinez Moreno",
	"name", "  Flavio Silvestrow",
	"name", "  Daniel Burrows",
	"name", "  Dave Turner",
	"name", "  Ben Hines",
	"name", "  Kachalov Anton",
	"title", "Past Patch Contributors",
	"name", "  Martin Hajduch",
	"name", "  Jeff Binder",
	"name", "  Ludovic",
	"name", "  Juan Pablo",
	"name", "  Phil Hannent",
	"name", "  Alexander MacLean",
	"name", "",
	"name", "Code used:",
	"name", "  SDL Copyright by Sam Lantinga",
	"name", "  ZZIPLIB Copyright by Tomi Ollil and Guido Draheim",
	"name", "  ZLIB Copyright by Jean-loup Gailly and Mark Adler",
	"name", "  BZ2LIB Copyright by Julian Seward",
	"name", "  PNG Copyright by Glenn Randers-Pehrson",
	"name", "  libmodplug Copyright by Kenton Varda & Olivier Lapique",
	"name", "  MAD Copyright by Robert Leslie",
	"name", "  OGG/Vorbis Copyright by Xiph.org Foundation",
	"name", "  FLAC Copyright by Josh Coalson",
	"name", "  VP3 codec Copyright by On2 Technologies Inc.",
	"name", "  Guichan Copyright by Per Larsson and Olof Naessen",
	"name", "  tolua++ Copyright by Codenix",
	"name", "",
	"name", "",
	"comment", "The Stratagus Team thanks all the people who have contributed",
	"comment", "patches, bug reports, ideas."
)
